package com.wim.deploy;

import com.ibm.broker.config.proxy.*;
import java.util.*;
import java.io.*;

public class DeployBrokerArchive {

	private String ipAddress = "";
	private int portNumber = 0;
	private String qMgr = "";

	private long timeToWait = 20 * 1000;

	private BrokerConnectionParameters bcp;
	private BrokerProxy bp;
	private ExecutionGroupProxy eg;

	private String barFileName = " ";
	private String execGroupName = " ";

	public void setDeployParms(String barFile, String execGrp) {
		barFileName = barFile;
		execGroupName = execGrp;
	}

	public void setBrokerProps(String propsFile) throws FileNotFoundException,
			IOException, Exception {
		Properties p = new Properties();
		p.load(new FileReader(propsFile));
		ipAddress = p.getProperty("ipAddress", "");
		portNumber = Integer.parseInt(p.getProperty("portNumber", "1414"));
		qMgr = p.getProperty("qMgr");
	}

	public void setProxyObjects() throws ConfigManagerProxyLoggedException, ConfigManagerProxyLoggedMQException,
			ConfigManagerProxyPropertyNotInitializedException {
		bcp = new MQBrokerConnectionParameters(ipAddress, portNumber, qMgr);
		bp = BrokerProxy.getInstance(bcp);
		eg = bp.getExecutionGroupByName(execGroupName);
	}
	
	public List<String> connProps() {
		List<String> l = new ArrayList<String>();

		l.add("Connecting to Queue Manager " + qMgr + " at IP address "
				+ ipAddress + " on port " + Integer.toString(portNumber));
		
		return l;
	}

	public List<String> brokerProps()
			throws ConfigManagerProxyPropertyNotInitializedException {
		List<String> l = new ArrayList<String>();

		l.add("Broker OS Architecture " + bp.getBrokerOSArch());
		l.add("Broker OS Name " + bp.getBrokerOSName());
		l.add("Broker OS Version " + bp.getBrokerOSVersion());
		l.add("Broker version " + Integer.toString(bp.getBrokerVersion()));
		l.add("Broker long version " + bp.getBrokerLongVersion());

		return l;
	}

	public List<String> execGroupProps()
			throws ConfigManagerProxyPropertyNotInitializedException {
		List<String> l = new ArrayList<String>();

		l.add("Execution group " + eg.getName() + " running is "
				+ Boolean.toString(eg.isRunning()));

		return l;
	}

	public List<String> barFileProps() throws IOException {
		BarFile bf = BarFile.loadBarFile(barFileName);
		List<String> l = new ArrayList<String>();

		l.add("Deploying BAR file " + bf.getFullName());
		l.add("BAR file valid is " + Boolean.toString(BarFile.isValid(barFileName)));

		Enumeration<BarEntry> e = bf.getBarEntries();

		for (; e.hasMoreElements();) {
			BarEntry be = (BarEntry) e.nextElement();
			String barEntryName = be.getFullName();
			String modifiedDate = be.getModifyTime().toString();

			l.add("BAR Entry " + barEntryName + " modified date "
					+ modifiedDate);
		}

		return l;
	}

	public int doDeploy() throws FileNotFoundException, IOException,
			ConfigManagerProxyLoggedException, Exception {

		DeployResult dr = eg.deploy(barFileName, false, timeToWait);

		if (dr.getCompletionCode() != CompletionCodeType.success) {
			throw new Exception("Deployment result "
					+ dr.getCompletionCode().intValue() + " "
					+ dr.getCompletionCode().toString());
		}

		return dr.getCompletionCode().intValue();

	}
}
